@@ -8,13 +8,12 @@
  */
 
 #include "kiobluetooth.h"
-#include "kdedbluedevil.h"
-#include "version.h"
 #include "filereceiversettings.h"
+#include "version.h"
 
-#include <QThread>
 #include <QCoreApplication>
 #include <QDBusMetaType>
+#include <QThread>
 
 #include <KLocalizedString>
 
@@ -59,8 +58,7 @@ KioBluetooth::KioBluetooth(const QByteArray &pool, const QByteArray &app)
 
     qCDebug(BLUETOOTH) << "Kio Bluetooth instanced!";
 
-    m_kded = new org::kde::BlueDevil(QStringLiteral("org.kde.kded5"), QStringLiteral("/modules/bluedevil"),
-                                     QDBusConnection::sessionBus());
+    m_kded = new org::kde::BlueDevil(QStringLiteral("org.kde.kded5"), QStringLiteral("/modules/bluedevil"), QDBusConnection::sessionBus());
 
     if (!m_kded->isOnline()) {
         qCDebug(BLUETOOTH) << "Bluetooth is offline";
@@ -154,7 +152,7 @@ void KioBluetooth::listDevices()
     const QMapDeviceInfo &devices = m_kded->allDevices().value();
     qCDebug(BLUETOOTH) << devices.keys();
 
-    Q_FOREACH(const DeviceInfo &device, devices) {
+    Q_FOREACH (const DeviceInfo &device, devices) {
         listDevice(device);
     }
 
